==> lxqt-config_0.14.1.1+rb2.orig.tar.xz: lxqt-config-0.14.1.1+rb2/liblxqt-config-cursor/translations/lxqt-config-cursor_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuración de tema do rato de LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Seleccione o tema de cursor que queira empregar (pase o cursor por riba para ter unha vista previa). &lt;b&gt;Após este cambio é necesario reiniciar a sesión de LXQt&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar un tema novo...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Retirar o tema</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>Produciuse un erro de XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Non pode retirar o tema activo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt non foi quen de atopar ningún tema de cursores. Usarase o tema de cursor preestabelecido de X11. LXQt buscou nos seguintes directorios:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Amosar...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.17.1.orig.tar.xz: lxqt-config-0.17.1/liblxqt-config-cursor/translations/lxqt-config-cursor_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuración de tema do rato de LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Seleccione o tema de cursor que queira empregar (pase o cursor por riba para ter unha vista previa). &lt;b&gt;Após este cambio é necesario reiniciar a sesión de LXQt&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar un tema novo...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>É necesario reiniciar a sesión LXQt para ver este cambio.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Retirar o tema</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="233"/>
        <source>XCurTheme error</source>
        <translation>Produciuse un erro de XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="234"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Non pode retirar o tema activo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt non foi quen de atopar ningún tema de cursores. Usarase o tema de cursor preestabelecido de X11. LXQt buscou nos seguintes directorios:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Amosar...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
</TS>
